==> muscle_5.1.0.orig.tar.gz: muscle-5.1.0/src/sequence.h <==
#ifndef SEQUENCE_H
#define SEQUENCE_H

#include <string>
#include <vector>
#include <fstream>
#include <iostream>
#include <cctype>
#include <cstdlib>
#include "filebuffer.h"

#define SEQ_TRACE	0

class Sequence;

// m_CharVec uses one-based indexing, m_CharVec[0] set to '@'.
class Sequence
	{
public:
#if SEQ_TRACE
	uint m_Id = UINT_MAX;
#endif

// Global input MulitSquence index
	uint m_GSI = UINT_MAX;

// Sparse matrix index
	uint m_SMI = UINT_MAX;

	string m_Label;
	vector<char> m_CharVec;

private:
	Sequence()
		{
#if SEQ_TRACE
		m_Id = UINT_MAX;
#endif
		m_Label = "~";
		m_GSI = UINT_MAX;
		m_SMI = UINT_MAX;
		}
	~Sequence() {}

public:
	bool FromFileBuffer(FileBuffer& infile, bool stripGaps = false);

	void Create(const vector<char> *m_CharVec, string m_Label,
	  uint GSI, uint SMI);

	void FromString(const string &Label, const string &Seq);
//	void Copy(const Sequence &rhs);

	void InitData()
		{
		m_CharVec.clear();
		m_CharVec.push_back('@');
		}

	void AppendChar(char c)
		{
		m_CharVec.push_back(c);
		}

	const string &GetLabel() const
		{
		return m_Label;
		}

	const char *GetLabelCStr() const
		{
		return m_Label.c_str();
		}

// One-based
	char *GetCharPtr1()
		{
		return m_CharVec.data();
		}

	const char *GetCharPtr1() const
		{
		return m_CharVec.data();
		}

	const byte *GetBytePtr() const
		{
		const char *CharPtr = m_CharVec.data() + 1;
		const byte *BytePtr = (const byte *) CharPtr;
		return BytePtr;
		}

// Chars stored with one-based indexing.
	char GetPosition(int i) const
		{
		assert(i >= 1 && i < m_CharVec.size());
		return m_CharVec[i];
		}

	char GetChar(uint ZeroBasedPos) const
		{
		return GetPosition(int(ZeroBasedPos+1));
		}

	void SetGSI(uint GSI)
		{
		asserta(m_GSI == UINT_MAX);
		m_GSI = GSI;
		}

	void OverwriteGSI(uint GSI)
		{
		m_GSI = GSI;
		}

	void OverwriteLabel(const string &Label)
		{
		m_Label = Label;
		}

	uint GetSMI() const
		{
		return m_SMI;
		}

	uint GetGSI() const
		{
		return m_GSI;
		}

	uint GetLength() const
		{
		uint n = (uint) m_CharVec.size();
		asserta(n > 0);
		uint L = n - 1;
		return L;
		}

	void WriteMFA(FILE *f) const;
	Sequence* Clone() const;
	Sequence* AddGaps(const vector<char>* alignment, char id) const;
	Sequence* AddGapsPath(const string &Path, char id) const;
	Sequence* DeleteGaps() const;
	void GetPosToCol_OneBased(vector<uint> &PosToCol) const;
	void GetPosToCol(vector<uint> &PosToCol) const;
	void GetColToPos(vector<uint> &ColToPos) const;
	void LogMe() const;
#if SEQ_TRACE
	void AssertId() const;
#endif

public:
#if SEQ_TRACE

	static Sequence *_NewSequence(const char *File, int Line);
#define NewSequence()	Sequence::_NewSequence(__FILE__, __LINE__)
	static void _DeleteSequence(const Sequence *Seq,
	  const char *File, int Line);
#define DeleteSequence(s)	Sequence::_DeleteSequence((s), __FILE__, __LINE__)
	static void AllocReport(const string &Msg);

#else

	static Sequence *_NewSequence();
#define NewSequence()	Sequence::_NewSequence()
	static void _DeleteSequence(const Sequence *Seq);
#define DeleteSequence(s)	Sequence::_DeleteSequence((s))

#endif
	};

#endif

==> muscle-5.2.tar.gz: muscle-5.2/src/sequence.h <==
#ifndef SEQUENCE_H
#define SEQUENCE_H

#include <string>
#include <vector>
#include <fstream>
#include <iostream>
#include <cctype>
#include <cstdlib>
#include "filebuffer.h"

//static const char LEFT_TERM_PAD_CHAR = '<';
//static const char RIGHT_TERM_PAD_CHAR = '>';
//static const uint TERM_PAD_LENGTH = 3;

class Sequence
	{
public:
	string m_Label;
	vector<char> m_CharVec;

private:
	Sequence() {}
	~Sequence() {}

public:
	bool FromFileBuffer(FileBuffer& infile, bool stripGaps = false);
	void FromString(const string &Label, const string &Seq);

	void InitData()
		{
		m_CharVec.clear();
		}

	void AppendChar(char c)
		{
		m_CharVec.push_back(c);
		}

	const string &GetLabel() const
		{
		return m_Label;
		}

	const char *GetLabelCStr() const
		{
		return m_Label.c_str();
		}

	const char *GetCharPtr() const
		{
		const char *CharPtr = m_CharVec.data();
		return CharPtr;
		}

	const byte *GetBytePtr() const
		{
		const char *CharPtr = m_CharVec.data();
		const byte *BytePtr = (const byte *) CharPtr;
		return BytePtr;
		}

	char GetChar(uint i) const
		{
		assert(i >= 0 && i < m_CharVec.size());
		return m_CharVec[i];
		}

	void OverwriteLabel(const string &Label)
		{
		m_Label = Label;
		}

	uint GetLength() const
		{
		return SIZE(m_CharVec);
		}

	void WriteMFA(FILE *f) const;
	Sequence *Clone() const;
	Sequence *AddGapsPath(const string &Path, char id) const;
	Sequence *CopyDeleteGaps() const;
	void GetPosToCol(vector<uint> &PosToCol) const;
	void GetColToPos(vector<uint> &ColToPos) const;
	void LogMe() const;
	void GetSeqAsString(string &Seq) const;
public:
	static Sequence *_NewSequence();
#define NewSequence()	Sequence::_NewSequence()
	static void _DeleteSequence(const Sequence *Seq);
#define DeleteSequence(s)	Sequence::_DeleteSequence((s))

	static void LogNewDeleteCounts();
	};

#endif
